# Dikkat lütfen!

Bu deney OpenSesame'nin daha yeni bir sürümü ile hazırlanmıştır.

OpenSesame'nin bu versiyonunun deneyi çalıştırıp çalıştırmayacağından emin değilim. OpenSesame'nin yeni sürümünü yuklemenizi öneririm. Eğer bu mümkün değilse deneyinizi yeni bir isimle kaydedin.

Ne yapmak istersiniz?

[Deneyi şimdi kaydet](opensesame://action.save){: .important-button} <br />

ya da:

[Bu mesajı sonsuza kadar yoksay](opensesame://event.os3n_dismiss_old_experiment){: .dismiss-button}
